"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const async_retry_1 = __importDefault(require("async-retry"));
const axios_1 = __importDefault(require("axios"));
const kleur_1 = require("kleur");
const qaWolfUrl = process.env.QAWOLF_URL || "https://www.qawolf.com";
const createSuite = async ({ env, triggerId, }) => {
    const suitesUrl = new URL("/api/suites", qaWolfUrl).href;
    const { data: { id, url }, } = await axios_1.default.post(suitesUrl, { env, trigger_id: triggerId }, { headers: { authorization: process.env.QAWOLF_API_KEY } });
    console.log("Created suite, see details at", url);
    return id;
};
const ensureApiKey = () => {
    if (!process.env.QAWOLF_API_KEY) {
        console.log(kleur_1.red("Error: must set QAWOLF_API_KEY environment variable"));
        process.exit(1);
    }
};
const waitForSuite = async (suiteId) => {
    console.log("waiting for tests to run...");
    const suiteUrl = new URL(`/api/suites/${suiteId}`, qaWolfUrl).href;
    const intervalMs = 10 * 1000; // 10 seconds
    const timeoutMs = 30 * 60 * 1000; // 30 minutes
    let timeout = false;
    const requestPromise = async_retry_1.default(async () => {
        if (timeout)
            return;
        const { data } = await axios_1.default.get(suiteUrl, {
            headers: { authorization: process.env.QAWOLF_API_KEY },
        });
        if (!data.is_complete)
            throw new Error("suite not complete");
        return data.status;
    }, {
        factor: 1,
        maxTimeout: intervalMs,
        minTimeout: intervalMs,
        retries: Math.round(timeoutMs / intervalMs),
    });
    const timeoutPromise = new Promise((_, reject) => {
        setTimeout(() => {
            timeout = true;
            reject(new Error("suite not complete"));
        }, timeoutMs);
    });
    return Promise.race([requestPromise, timeoutPromise]);
};
async function runTests({ env, triggerId, wait, }) {
    console.log(kleur_1.bold(`\n🐺  Run QA Wolf tests for trigger ${triggerId}`));
    ensureApiKey();
    const suiteId = await createSuite({ env, triggerId });
    if (!wait)
        return;
    const status = await waitForSuite(suiteId);
    const colorFn = status === "fail" ? kleur_1.red : kleur_1.green;
    console.log(colorFn(`🐺 complete, suite ${status}ed`));
    if (status === "pass")
        return;
    process.exit(1);
}
exports.default = runTests;
//# sourceMappingURL=runTests.js.map